ExMCP.Authorization.JWTBearerAssertion (ex_mcp v0.9.0)

RFC 7523 Section 2.1 — JWT Bearer Grant.

Uses a JWT assertion as an authorization grant to obtain an access token. This is used in the enterprise-managed authorization flow (Step 3) where the ID-JAG is presented to the authorization server as a JWT bearer grant.

Summary

Functions

Performs a JWT bearer grant at the token endpoint.

Returns the JWT bearer grant type URI.

Functions

grant(opts)

@spec grant(keyword()) :: {:ok, map()} | {:error, term()}

Performs a JWT bearer grant at the token endpoint.

Options

  • :token_endpoint (required) - The authorization server's token endpoint
  • :assertion (required) - The JWT assertion (e.g., an ID-JAG)
  • :client_id - Client identifier (optional, may be implicit in assertion)
  • :scope - Requested scope
  • :resource - Target resource URI (RFC 8707)

grant_type()

Returns the JWT bearer grant type URI.