mix test.tags (ex_mcp v0.9.0)
View SourceList and describe test tags used in ExMCP.
Usage
mix test.tagsThis will display all available test tags and their descriptions.
List and describe test tags used in ExMCP.
mix test.tagsThis will display all available test tags and their descriptions.