ExMCP.ErrorHelpers (ex_mcp v0.9.0)
View SourceHelper functions for creating ExMCP.Error structs. This module provides backward compatibility for tests.
Summary
Functions
Creates a connection error that returns a main Error struct.
Creates an error struct from a JSON-RPC error response.
Creates an internal error.
Creates an invalid params error.
Creates an invalid request error.
Creates a method not found error.
Creates a parse error.
Creates a prompt error for the Error struct format.
Creates a resource error for the Error struct format.
Creates a tool error for the Error struct format.
Functions
Creates a connection error that returns a main Error struct.
Creates an error struct from a JSON-RPC error response.
Creates an internal error.
Creates an invalid params error.
Creates an invalid request error.
Creates a method not found error.
Creates a parse error.
Creates a prompt error for the Error struct format.
Creates a resource error for the Error struct format.
Creates a tool error for the Error struct format.